@@ -65,12 +65,15 @@ def prepare_test(production_name, job_name, dependent_input=None):
         "application": {
             "name": application_name,
             "version": application_version,
-            "data_pkgs": ["AnalysisProductions v999999999999", "ProdConf"],
+            "data_pkgs": ["AnalysisProductions v999999999999"],
         },
-        "options": {"format": "WGProd", "files": job_data["options"]},
         "input": {"xml_summary_file": "summaryDaVinci_00012345_00006789_1.xml"},
         "output": {"prefix": "00012345_00006789_1"},
     }
+    if isinstance(job_data["options"], dict):
+        prodrun_conf["options"] = job_data["options"].copy()
+    else:
+        prodrun_conf["options"] = {"format": "WGProd", "files": job_data["options"]}
 
     override_input, output_filetype = resolve_input_overrides(prod_data, job_name)
     if "job_name" in job_data["input"] and dependent_input is None:
@@ -86,6 +89,10 @@ def prepare_test(production_name, job_name, dependent_input=None):
     dynamic_dir, out_dir = create_output_dir(production_name, require_cmt)
 
     if job_data["automatically_configure"]:
+        if "files" not in prodrun_conf["options"]:
+            raise NotImplementedError(
+                "automatically_configure is not yet supported for lbexec based productions"
+            )
         params = {}
         if output_filetype:
             params["override-output-filetype"] = output_filetype
